==> alt-ergo_0.91.orig.tar.gz: alt-ergo-0.91/main.ml <==
(**************************************************************************)
(*                                                                        *)
(*     The Alt-ergo theorem prover                                        *)
(*     Copyright (C) 2006-2010                                            *)
(*                                                                        *)
(*     Sylvain Conchon                                                    *)
(*     Evelyne Contejean                                                  *)
(*     Stephane Lescuyer                                                  *)
(*     Mohamed Iguernelala                                                *)
(*     Alain Mebsout                                                      *)
(*                                                                        *)
(*     CNRS - INRIA - Universite Paris Sud                                *)
(*                                                                        *)
(*   This file is distributed under the terms of the CeCILL-C licence     *)
(*                                                                        *)
(**************************************************************************)

open Why_ptree

let _ = 
  Sys.set_signal Sys.sigint 
    (Sys.Signal_handle 
       (fun _ -> print_endline "User wants me to stop."; exit 1))

open Lexing
open Format
open Options

module Time = struct

  open Unix
    
  let u = ref 0.0
    
  let start () = u:=(times()).tms_utime

  let get () = (times()).tms_utime -. !u

end

let print_status fmt s = 
  fprintf fmt "%s@."
    ((function 
	| Smt_ast.Unsat -> "unsat" 
	| Smt_ast.Unknown -> "unknown"
	| Smt_ast.Sat  -> "unknown (sat)") s)

let process_decl (env,consistent) d =
  let satmode = !smtfile or !satmode in
  try
    match d.st_decl with
      | Assume(f,mf) -> 
	  Sat.assume env {Sat.f=f;age=0;name=None;mf=mf;gf=false}, consistent

      |	PredDef f -> 
	  Sat.pred_def env f , consistent

      | Query(n,f,lits)-> 
	  if consistent then
	    begin
	      Sat.unsat env 
		{Sat.f=f;age=0;name=None;mf=true;gf=true} stopb ; 
	      if not satmode then Loc.report d.st_loc
	    end;
	  if satmode then printf "@{<C.F_Red>unsat@}@." 
	  else printf "@{<C.F_Green>Valid@} (%2.4f)@." (Time.get());
	  env , consistent
  with 
    | Sat.Sat -> 
	if not satmode then Loc.report d.st_loc;
	if satmode then printf "unknown (sat)@." 
	else printf "I don't know@."; 
	env , consistent
    | Sat.Unsat -> 
	if not satmode then 
	  (Loc.report d.st_loc; 
	   fprintf fmt "Inconsistent assumption@.")
	else printf "unsat@.";
	env , false
    | Sat.I_dont_know -> 
	if not satmode then (Loc.report d.st_loc; printf "I don't know.@.")
	else printf "unknown@.";
	env , consistent

let get_smt_prelude () =
  let libdir =
    try Sys.getenv "ERGOLIB"
    with Not_found -> Version.libdir
  in
  let f = Filename.concat libdir "smt_prelude.mlw"
  in
  from_channel (open_in f)

let open_file file lb =
  let d ,status =
    if !smtfile then begin
      let lb_prelude = get_smt_prelude () in 
      let lp = Why_parser.file Why_lexer.token lb_prelude in
      let bname,l,status = Smt_parser.benchmark Smt_lex.token lb in
      if verbose then printf "converting smt file : ";
      let l = List.flatten (List.map Smt_to_why.bench_to_why l) in
      if verbose then printf "done.@.";
      if parse_only then exit 0;
      Why_typing.file (lp@l) , status
    end
    else
      (let a = Why_parser.file Why_lexer.token lb in
       if parse_only then exit 0;
       Why_typing.file a) , Smt_ast.Unknown
  in
  if file <> " stdin" then close_in cin;
  if type_only then exit 0;
  d, status

let pruning = 
  List.map
    (fun d -> 
       if select > 0 then Pruning.split_and_prune select d 
       else [List.map (fun f -> f,true) d])
    
let processing declss = 
  List.iter
    (List.iter 
       (fun dcl ->
	  let cnf = Why_typing.make_cnf dcl in 
	  ignore (Queue.fold process_decl (Sat.empty,true) cnf)
       )) (pruning declss)

let main _ = 
  let lb = from_channel cin in 
  try let d, status = open_file !file lb in processing d
  with
    | Why_lexer.Lexical_error s -> 
	Loc.report (lexeme_start_p lb, lexeme_end_p lb);
	printf "lexical error: %s\n@." s;
	exit 1
    | Parsing.Parse_error ->
	let  loc = (lexeme_start_p lb, lexeme_end_p lb) in
	Loc.report loc;
        printf "syntax error\n@.";
	exit 1
    | Why_typing.Error(e,l) -> 
	Loc.report l; 
	printf "typing error: %a\n@." Why_typing.report e;
	exit 1

let _ = main ()

==> alt-ergo_0.93.orig.tar.gz: alt-ergo-0.93/main.ml <==
(**************************************************************************)
(*                                                                        *)
(*     The Alt-ergo theorem prover                                        *)
(*     Copyright (C) 2006-2010                                            *)
(*                                                                        *)
(*     Sylvain Conchon                                                    *)
(*     Evelyne Contejean                                                  *)
(*     Stephane Lescuyer                                                  *)
(*     Mohamed Iguernelala                                                *)
(*     Alain Mebsout                                                      *)
(*                                                                        *)
(*     CNRS - INRIA - Universite Paris Sud                                *)
(*                                                                        *)
(*   This file is distributed under the terms of the CeCILL-C licence     *)
(*                                                                        *)
(**************************************************************************)

open Why_ptree
open Frontend

open Lexing
open Format
open Options

let _ = 
  Sys.set_signal Sys.sigint 
    (Sys.Signal_handle 
       (fun _ -> print_endline "User wants me to stop."; exit 1))	  



let print_status d s steps =
  let satmode = !smtfile or !smt2file or !satmode in 
  match s with
    | Unsat dep -> 
	if not satmode then Loc.report d.st_loc;
	if satmode then printf "@{<C.F_Red>unsat@}@." 
	else printf "@{<C.F_Green>Valid@} (%2.4f) (%Ld)@." (Time.get()) steps;
	if proof && not debug_proof then 
          printf "Proof:\n%a@." Explanation.print_proof dep
	  
    | Inconsistent ->
	if not satmode then 
	  (Loc.report d.st_loc; 
	   fprintf fmt "Inconsistent assumption@.")
	else printf "unsat@."
	  
    | Unknown ->
	if not satmode then
	  (Loc.report d.st_loc; printf "I don't know.@.")
	else printf "unknown@."
	  
    | Sat  -> 
	if not satmode then Loc.report d.st_loc;
	if satmode then printf "unknown (sat)@." 
	else printf "I don't know@."



let main _ = 
  let lb = from_channel cin in 
  try 
    let d, status = open_file !file lb in 
    processing print_status d
  with
    | Why_lexer.Lexical_error s -> 
	Loc.report (lexeme_start_p lb, lexeme_end_p lb);
	printf "lexical error: %s\n@." s;
	exit 1
    | Parsing.Parse_error ->
	let  loc = (lexeme_start_p lb, lexeme_end_p lb) in
	Loc.report loc;
        printf "syntax error\n@.";
	exit 1
    | Common.Error(e,l) -> 
	Loc.report l; 
	printf "typing error: %a\n@." Common.report e;
	exit 1

let _ = main ();
